summaryrefslogtreecommitdiffstats
path: root/src/com/android/providers/downloads/SystemFacade.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/providers/downloads/SystemFacade.java')
-rw-r--r--src/com/android/providers/downloads/SystemFacade.java12
1 files changed, 9 insertions, 3 deletions
diff --git a/src/com/android/providers/downloads/SystemFacade.java b/src/com/android/providers/downloads/SystemFacade.java
index e16e6a06..2addbf82 100644
--- a/src/com/android/providers/downloads/SystemFacade.java
+++ b/src/com/android/providers/downloads/SystemFacade.java
@@ -1,7 +1,6 @@
package com.android.providers.downloads;
-import java.util.BitSet;
interface SystemFacade {
/**
@@ -10,12 +9,19 @@ interface SystemFacade {
public long currentTimeMillis();
/**
* @return Network types (as in ConnectivityManager.TYPE_*) of all connected networks.
*/
- public BitSet getConnectedNetworkTypes();
+ public Integer getActiveNetworkType();
/**
* @see android.telephony.TelephonyManager#isNetworkRoaming
*/
public boolean isNetworkRoaming();
+
+ /**
+ * @return maximum size, in bytes, of downloads that may go over a mobile connection; or null if
+ * there's no limit
+ */
+ public Integer getMaxBytesOverMobile();
}
@@ -10,12 +9,19 @@ interface SystemFacade {
public long currentTimeMillis();
/**
- * @return Network types (as in ConnectivityManager.TYPE_*) of all connected networks.
+ * @return Network type (as in ConnectivityManager.TYPE_*) of currently active network, or null
+ * if there's no active connection.
*/